Installation
============

Installing papermill
--------------------

From the command line:

*Python 3*

.. code-block:: bash

   python3 -m pip install papermill

*Python 2*

.. code-block:: bash

   python -m pip install papermill

If unsure whether to use Python 3 or Python 2, we recommend using Python 3.

Installing In-Notebook language bindings
----------------------------------------

In-Notebook language bindings provide helpers and utilities for using Papermill
with a programming language.

Python bindings
~~~~~~~~~~~~~~~

No additional installation steps are required since `Python`_ bindings are built
into **papermill**.

R bindings
~~~~~~~~~~

The R language bindings are provided by the **papermillr** project. Follow
installation instructions for `R language bindings`_.

.. _`Python`: https://github.com/nteract/papermill/blob/master/README.md
.. _`R language bindings`: https://github.com/nteract/papermillr
